@@ -1,4 +1,4 @@
-# $Id: Custom.pm 844 2009-03-05 00:07:26Z rvos $
+# $Id: Custom.pm 1593 2011-02-27 15:26:04Z rvos $
 package Bio::Phylo::Matrices::Datatype::Custom;
 use strict;
 use vars qw(@ISA);
@@ -33,9 +33,18 @@ Also see the manual: L<Bio::Phylo::Manual> and L<http://rutgervos.blogspot.com>.
 
 =back
 
+=head1 CITATION
+
+If you use Bio::Phylo in published research, please cite it:
+
+B<Rutger A Vos>, B<Jason Caravas>, B<Klaas Hartmann>, B<Mark A Jensen>
+and B<Chase Miller>, 2011. Bio::Phylo - phyloinformatic analysis using Perl.
+I<BMC Bioinformatics> B<12>:63.
+L<http://dx.doi.org/10.1186/1471-2105-12-63>
+
 =head1 REVISION
 
- $Id: Custom.pm 844 2009-03-05 00:07:26Z rvos $
+ $Id: Custom.pm 1593 2011-02-27 15:26:04Z rvos $
 
 =cut
 
