@@ -1,4 +1,4 @@
-# $Id: Matrix.pm 1593 2011-02-27 15:26:04Z rvos $
+# $Id: Matrix.pm 1634 2011-03-30 17:02:17Z rvos $
 package Bio::Phylo::Matrices::Matrix;
 use vars '@ISA';
 use strict;
@@ -10,6 +10,7 @@ use Bio::Phylo::Util::CONSTANT qw(
 	looks_like_hash 
 	looks_like_instance 
 	looks_like_number
+	looks_like_object
 );
 use Bio::Phylo::Util::Exceptions qw(throw);
 use Bio::Phylo::NeXML::Writable ();
@@ -44,6 +45,7 @@ my $LOADED_WRAPPERS = 0;
 			%matchchar,
 			%polymorphism,
 			%case_sensitivity,
+			%characters,
 		)
 	);
 
@@ -185,7 +187,29 @@ Matrix constructor.
 		}		
 
 		# go up inheritance tree, eventually get an ID
-		my $self = $class->SUPER::new( @_ );
+		my $self = $class->SUPER::new(
+			'-characters' => $factory->create_characters,
+			'-listener'   => sub {
+				my $self = shift;
+				my $nchar = $self->get_nchar;
+				my $characters = $self->get_characters;
+				my @chars = @{ $characters->get_entities };
+				my @defined = grep { defined $_ } @chars;
+				if ( scalar @defined != $nchar ) {
+					for my $i ( 0 .. ( $nchar - 1 ) ) {
+						if ( not $chars[$i] ) {
+							$characters->insert_at_index( $factory->create_character, $i );
+						}
+					}
+				}
+				@chars = @{ $characters->get_entities };
+				if ( scalar(@chars) > $nchar ) {
+					$characters->prune_entities([$nchar .. $#chars]);
+				}
+			},
+			@_
+		);
+		
 		return $self;
 	}
 
@@ -367,6 +391,28 @@ Sets argument state labels.
 		return $self;		
 	}
 
+=item set_characters()
+
+Sets the character set manager object Bio::Phylo::Matrices::Characters.
+Normally you never have to use this.
+
+ Type    : Mutator
+ Title   : set_characters
+ Usage   : $matrix->set_characters( $characters );
+ Function: Assigns Bio::Phylo::Matrices::Characters object
+ Returns : $self
+ Args    : Bio::Phylo::Matrices::Characters
+
+=cut
+
+	sub set_characters {
+		my ( $self, $characters ) = @_;
+		if ( looks_like_object $characters, _CHARACTERS_ ) {
+			$characters{ $self->get_id } = $characters;
+		}
+		return $self;
+	}
+
 =item set_charlabels()
 
 Sets argument character labels.
@@ -398,7 +444,10 @@ Sets argument character labels.
 		}
 
 		# it's either a valid array ref, or nothing, i.e. a reset
-		$charlabels{$self->get_id} = defined $charlabels ? $charlabels : [];
+		my @characters = @{ $self->get_characters->get_entities };
+		for my $i ( 0 .. $#{ $charlabels } ) {
+			$characters[$i]->set_name( $charlabels->[$i] );
+		}
 		return $self;
 	}
 
@@ -562,6 +611,24 @@ Retrieves hash ref for missing, gap and matchchar symbols
 		};
 	}
 
+=item get_characters()
+
+Retrieves characters object.
+
+ Type    : Accessor
+ Title   : get_characters
+ Usage   : my $characters = $matrix->get_characters
+ Function: Retrieves characters object.
+ Returns : Bio::Phylo::Matrices::Characters
+ Args    : None.
+
+=cut
+
+	sub get_characters {
+		my $self = shift;
+		return $characters{ $self->get_id };
+	}
+
 =item get_statelabels()
 
 Retrieves state labels.
@@ -590,7 +657,11 @@ Retrieves character labels.
 
 =cut
 
-	sub get_charlabels { $charlabels{ $_[0]->get_id } || [] }
+	sub get_charlabels {
+		my $self = shift;
+		my @labels = map { $_->get_name } @{ $self->get_characters->get_entities };
+		return \@labels;
+	}
 
 =item get_gapmode()
 
@@ -1153,7 +1224,7 @@ Insert argument in invocant.
 		return $self;
 	}
 
-=item validate()
+=begin comment
 
 Validates the object's contents.
 
@@ -1166,13 +1237,12 @@ Validates the object's contents.
  Comments: This method implements the interface method by the same
            name in Bio::Phylo::Matrices::TypeSafeData
 
+=end comment
+
 =cut
 
-	sub validate {
-		my $self = shift;
-		for my $row ( @{ $self->get_entities } ) {
-			$row->validate;
-		}
+	sub _validate {
+		shift->visit( sub { shift->validate } );
 	}
 
 =item compress_lookup()
@@ -1339,21 +1409,12 @@ Serializes matrix to nexml format.
 		$xml .= $to->to_xml($normalized,$self->get_polymorphism);
 		$logger->debug($xml);
 		
-		# write column definitions
-		if ( %{ $ids_for_states } ) {
-			$xml .= $self->_write_char_labels( $to->get_xml_id );
-		}
-		else {
-			$xml .= $self->_write_char_labels();
-		}
+		$xml .= $self->get_characters->to_xml;
 		$xml .= "\n</format>";
 		
 		# the matrix block
 		$xml .= "\n<matrix>";
-		my @char_ids;
-		for ( 0 .. $self->get_nchar ) {
-			push @char_ids, 'c' . ($_+1);
-		}
+		my @char_ids = map { $_->get_xml_id } @{ $self->get_characters->get_entities };
 		
 		# write rows
 		my $special = $self->get_type_object->get_ids_for_special_symbols(1);
@@ -1397,23 +1458,6 @@ Serializes matrix to nexml format.
 			return {};
 		}
 	}
-	
-	sub _write_char_labels {
-		my ( $self, $states_id ) = @_;
-		my $xml = '';
-		my $labels = $self->get_charlabels;
-		for my $i ( 1 .. $self->get_nchar ) {
-			$xml .= sprintf('<char id="c%s"',$i);  
-			if ( $labels->[ $i - 1 ] ) {
-				$xml .= sprintf(' label="%s"', $labels->[ $i - 1 ]);
-			}
-			if ( $states_id ) {
-				$xml .= sprintf(' states="%s"', $states_id);
-			}
-			$xml .= '/>';
-		}	
-		return $xml;	
-	}
 
 =item to_nexus()
 
@@ -1759,7 +1803,7 @@ L<http://dx.doi.org/10.1186/1471-2105-12-63>
 
 =head1 REVISION
 
- $Id: Matrix.pm 1593 2011-02-27 15:26:04Z rvos $
+ $Id: Matrix.pm 1634 2011-03-30 17:02:17Z rvos $
 
 =cut
 
