@@ -1,4 +1,4 @@
-#$Id: Libxml.pm 1401 2010-10-22 15:02:22Z rvos $
+#$Id: Libxml.pm 1593 2011-02-27 15:26:04Z rvos $
 
 =head1 NAME
 
@@ -503,6 +503,15 @@ sub to_xml {
 
 =back
 
+=head1 CITATION
+
+If you use Bio::Phylo in published research, please cite it:
+
+B<Rutger A Vos>, B<Jason Caravas>, B<Klaas Hartmann>, B<Mark A Jensen>
+and B<Chase Miller>, 2011. Bio::Phylo - phyloinformatic analysis using Perl.
+I<BMC Bioinformatics> B<12>:63.
+L<http://dx.doi.org/10.1186/1471-2105-12-63>
+
 =cut
 
 1;
