@@ -1,4 +1,4 @@
-# $Id: Writable.pm 1593 2011-02-27 15:26:04Z rvos $
+# $Id: Writable.pm 1628 2011-03-30 16:35:09Z rvos $
 package Bio::Phylo::NeXML::Writable;
 use strict;
 use Bio::Phylo ();
@@ -12,6 +12,7 @@ use Bio::Phylo::Util::CONSTANT qw(
 	looks_like_hash
 	looks_like_instance
 	looks_like_implementor
+	looks_like_class
 	:namespaces
 );
 use vars '@ISA';
@@ -833,12 +834,7 @@ Serializes object to JSON string
 =cut
 
     sub to_json { 
-	my $self = shift;
-    	eval { require XML::XML2JSON };
-    	if ( $@ ) {
-    		throw 'ExtensionError' => "Can't load XML::XML2JSON - $@";    		
-    	}
-	return XML::XML2JSON->new->convert($self->to_xml);
+	looks_like_class('XML::XML2JSON')->new->convert(shift->to_xml);
     }
 
 	sub _cleanup { 
@@ -870,7 +866,7 @@ L<http://dx.doi.org/10.1186/1471-2105-12-63>
 
 =head1 REVISION
 
- $Id: Writable.pm 1593 2011-02-27 15:26:04Z rvos $
+ $Id: Writable.pm 1628 2011-03-30 16:35:09Z rvos $
 
 =cut
 
