@@ -1,4 +1,4 @@
-# $Id: Taxlist.pm 1524 2010-11-25 19:24:12Z rvos $
+# $Id: Taxlist.pm 1593 2011-02-27 15:26:04Z rvos $
 package Bio::Phylo::Parsers::Taxlist;
 use strict;
 use Bio::Phylo::Parsers::Abstract;
@@ -51,9 +51,18 @@ Also see the manual: L<Bio::Phylo::Manual> and L<http://rutgervos.blogspot.com>.
 
 =back
 
+=head1 CITATION
+
+If you use Bio::Phylo in published research, please cite it:
+
+B<Rutger A Vos>, B<Jason Caravas>, B<Klaas Hartmann>, B<Mark A Jensen>
+and B<Chase Miller>, 2011. Bio::Phylo - phyloinformatic analysis using Perl.
+I<BMC Bioinformatics> B<12>:63.
+L<http://dx.doi.org/10.1186/1471-2105-12-63>
+
 =head1 REVISION
 
- $Id: Taxlist.pm 1524 2010-11-25 19:24:12Z rvos $
+ $Id: Taxlist.pm 1593 2011-02-27 15:26:04Z rvos $
 
 =cut
 
